# (Fedora) We require at the least the first release java-1.6.0-openjdk 
# with IcedTea6 1.10
%define min_openjdk_version 0:1.6.0.0-14.b22.3
%define multilib_arches ppc64 sparc64 x86_64

# Version of java
%define javaver 1.6.0

# Alternatives priority
%define priority 16000

%ifarch %{ix86}
%define archinstall i386
%endif
%ifarch x86_64
%define archinstall amd64
%endif
# 32 bit sparc, optimized for v9
%ifarch sparcv9
%define archinstall sparc
%endif
# 64 bit sparc
%ifarch sparc64
%define archinstall sparcv9
%endif

%ifarch %{multilib_arches}
%define javadir     %{_jvmdir}/java-%{javaver}-openjdk.%{_arch}
%define jredir      %{_jvmdir}/jre-%{javaver}-openjdk.%{_arch}
%define javaplugin  libjavaplugin.so.%{_arch}
%else
%define javadir     %{_jvmdir}/java-%{javaver}-openjdk
%define jredir      %{_jvmdir}/jre-%{javaver}-openjdk
%define javaplugin  libjavaplugin.so
%endif

Name:       icedtea-web
Version:    1.0.2
Release:    %mkrel 5
Summary:    Additional Java components for OpenJDK

Group:      Networking/WWW 
License:    LGPLv2+ and GPLv2 with exceptions
URL:        http://icedtea.classpath.org/wiki/IcedTea-Web
Source0:    http://icedtea.classpath.org/download/source/%{name}-%{version}.tar.gz

BuildRequires:  java-1.6.0-openjdk-devel
BuildRequires:  desktop-file-utils
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
BuildRequires:  xulrunner-devel
BuildRequires:  zip

# For functionality and the OpenJDK dirs
Requires:      java-1.6.0-openjdk >= %{min_openjdk_version}

Requires(post):   update-alternatives
Requires(postun): update-alternatives

# Standard JPackage plugin provides.
Provides: java-plugin = %{javaver}

Provides:   java-1.6.0-openjdk-plugin = %{min_openjdk_version}
Obsoletes:  java-1.6.0-openjdk-plugin <= %{min_openjdk_version}

# (Fedora) IcedTea is only built on these archs for now
ExclusiveArch: x86_64 %{ix86}

%description
The IcedTea-Web project provides a Java web browser plugin, an implementation
of Java Web Start (originally based on the Netx project) and a settings tool to
manage deployment settings for the aforementioned plugin and Web Start
implementations. 

%files
%defattr(-,root,root,-)
%doc NEWS README COPYING
%{jredir}/bin/*
%{jredir}/lib/*
%dir %{_libdir}/mozilla/plugins/
%{jredir}/man/man1/*
%{_datadir}/pixmaps/javaws.png
%{_datadir}/applications/javaws.desktop
%{_datadir}/applications/itweb-settings.desktop

#--------------------------------------------------------------------

%package javadoc
Summary:    API documentation for IcedTea-Web
Group:      Documentation
Requires:   jpackage-utils
BuildArch:  noarch

%description javadoc
This package contains Javadocs for the IcedTea-Web project.

%files javadoc
%defattr(-,root,root,-)
%doc COPYING
%{_javadocdir}/%{name}

#--------------------------------------------------------------------

%prep
%setup -q

%build
./configure \
    --with-pkgversion=%{_real_vendor}-%{release}-%{_arch} \
    --docdir=%{_javadocdir}/%{name} \
    --prefix=%{jredir}/

make CXXFLAGS="%optflags"

%install
%makeinstall_std

# (Fedora) Remove pluginappletviewer ... it is unused and will be removed in 1.1
rm -f %{buildroot}%{jredir}/bin/pluginappletviewer

# for update-alternatives to work
install -d -m 755 %{buildroot}%{_libdir}/mozilla/plugins/

# Install desktop files.
install -d -m 755 %{buildroot}%{_datadir}/{applications,pixmaps}
cp javaws.png %{buildroot}%{_datadir}/pixmaps
desktop-file-install --vendor ''\
  --dir %{buildroot}%{_datadir}/applications javaws.desktop
desktop-file-install --vendor ''\
  --dir %{buildroot}%{_datadir}/applications itweb-settings.desktop

%posttrans
update-alternatives --remove %{javaplugin} \
  %{javadir}/jre/lib/%{archinstall}/gcjwebplugin.so 2>/dev/null

update-alternatives --remove %{javaplugin} \
  %{jredir}/lib/%{archinstall}/IcedTeaNPPlugin.so 2>/dev/null

update-alternatives \
  --install %{_libdir}/mozilla/plugins/libjavaplugin.so %{javaplugin} \
  %{jredir}/lib/%{archinstall}/IcedTeaPlugin.so %{priority} \
  --slave %{_bindir}/javaws javaws %{jredir}/bin/javaws \
  --slave %{_mandir}/man1/javaws.1 javaws.1 %{jredir}/man/man1/javaws.1

exit 0

%postun
if [ $1 -eq 0 ]
then
  update-alternatives --remove %{javaplugin} \
    %{jredir}/lib/%{archinstall}/IcedTeaPlugin.so
fi

exit 0



%changelog
* Mon Apr 11 2011 tmb <tmb> 1.0.2-5.mga1
+ Revision: 83483
- fix ExclusiveArch so i586 gets built

* Mon Apr 11 2011 tmb <tmb> 1.0.2-4.mga1
+ Revision: 83472
- rebuild for missing package on i586

* Sat Apr 09 2011 dmorgan <dmorgan> 1.0.2-3.mga1
+ Revision: 82529
- Better obsoletes

* Sat Apr 09 2011 dmorgan <dmorgan> 1.0.2-2.mga1
+ Revision: 82525
- Fix openjdk version for the obsolete/provides
  Fix Groups
  Fix layout

* Sat Apr 09 2011 ahmad <ahmad> 1.0.2-1.mga1
+ Revision: 82490
- adapt the spec to Mageia
- add BR zip
- imported package icedtea-web


* Mon Apr 04 2011 Deepak Bhole <dbhole@redhat.com> 1.0.2-2
- Fixed incorrect macro value for min_openjdk_version
- Use posttrans instead of post, so that upgrade from old plugin works

* Mon Apr 04 2011 Deepak Bhole <dbhole@redhat.com> 1.0.2-1
- Initial build
